+++
title = "Voltage Amplifier"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}}), [Piezoelectric Actuators]({{< relref "piezoelectric_actuators" >}}), [Electronics]({{< relref "electronics" >}})


## Voltage Amplifiers to drive Capacitive Load {#voltage-amplifiers-to-drive-capacitive-load}


### Limitation in Current {#limitation-in-current}

The piezoelectric stack can be represented as a capacitance.

Let's take a capacitance driven by a voltage amplifier (Figure [1](#org0d9f468)).

<a id="org0d9f468"></a>

{{< figure src="/ox-hugo/voltage_amplifier_capacitance.png" caption="Figure 1: Piezoelectric actuator model with a voltage source" >}}

The equation linking the voltage to the current is:
\\[ I = C \frac{dU}{dt} \\]

Suppose we want to drive the piezo with a voltage:
\\[ U(t) = U\_0 \sin(\omega\_0 t) \\]

The required current is:
\\[ I = C U\_0 \omega\_0 \cos(\omega\_0 t) \\]

Thus, for a specified maximum current \\(I\_\text{max}\\), the "power bandwidth" will be:
\\[ \omega\_{0, \text{max}} = \frac{I\_\text{max}}{C U\_0}, \quad f\_{0, \text{max}} = \frac{I\_\text{max}}{C U\_0} \frac{1}{2 \pi} \\]

-   Below \\(\omega\_{0, \text{max}}\\), a voltage amplitude \\(U\_0\\) can be applied to the piezoelectric load without reaching the maximum current \\(I\_\text{max}\\).
-   Above \\(\omega\_{0, \text{max}}\\), the maximum current \\(I\_\text{max}\\) is reached and the maximum voltage that can be applied decreases with frequency:
    \\[ U\_\text{max} = \frac{I\_\text{max}}{\omega C} \\]

The maximum voltage as a function of frequency is shown in Figure [2](#org8625e7c).

```matlab
Vpkp = 170; % [V]
Imax = 30e-3; % [A]
C = 1e-6; % [F]

(1/(2*pi))*Imax/(C * Vpkp/2) % Fmax [Hz]
```

```text
56.172
```

<a id="org8625e7c"></a>

{{< figure src="/ox-hugo/voltage_amplifier_max_V_piezo.png" caption="Figure 2: Maximum voltage as a function of the frequency for \\(C = 1 \mu F\\), \\(I\_\text{max} = 30mA\\) and \\(V\_{pkp} = 170 V\\)" >}}

Similarly, the voltage rise time is determined by the Capacitance of the piezoelectric stack and by the maximum current that the amplifier can deliver:
\\[ t\_c = \frac{\Delta U C}{I\_\text{max}} \\]
with \\(t\_c\\) in seconds, \\(\Delta U\\) in volts, \\(C\\) in Farads and \\(I\_\text{max}\\) in Amperes.

If driven at \\(\Delta U = 100V\\), \\(C = 1 \mu F\\) and \\(I\_\text{max} = 1 A\\), then:
\\[ t\_c = \frac{100 \cdot 10^{-6}}{1} = 0.1 ms \\]


### Amplifiers for Low Voltage PZT {#amplifiers-for-low-voltage-pzt}

Piezoelectric Stack Actuators are behaving like capacitor for the Amplifiers.

Specifications are usually:

-   Maximum Current
-   DC Gain (usually around 10)
-   Output Noise or [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}})

The bandwidth can be estimated from the Maximum Current and the Capacitance of the Piezoelectric Actuator.

| Manufacturers       | Links                                                                                                                                                   |
|---------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------|
| Piezo Drive         | [link](https://www.piezodrive.com/drivers/)                                                                                                             |
| Thorlabs            | [link](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup%5Fid=13630)                                                                               |
| PI                  | [link](https://www.pi-usa.us/en/products/controllers-drivers-motion-control-software/piezo-drivers-controllers-power-supplies-high-voltage-amplifiers/) |
| Micromega Dynamics  |                                                                                                                                                         |
| Lab Systems         | [link](https://www.lab-systems.com/products/amplifier/amplifier.html)                                                                                   |
| Falco System        | [link](https://www.falco-systems.com/products.html)                                                                                                     |
| Piezomechanics      | [link](https://www.piezomechanik.com/products/)                                                                                                         |
| Cedrat Technologies | [link](https://www.cedrat-technologies.com/en/products/piezo-controllers/electronic-amplifier-boards.html)                                              |
| acal                | [link](https://www.acalbfi.com/nl/Electronic-test-and-measurement/High-voltage-amplifiers/c/CAT-06-03)                                                  |
| Trek                | [link](https://www.trekinc.com/products/HV%5FAmp.asp)                                                                                                   |
| Madcitylabs         | [link](http://www.madcitylabs.com/piezoactuators.html)                                                                                                  |

<./biblio/references.bib>


## Backlinks {#backlinks}

-   [Piezoelectric Actuators]({{< relref "piezoelectric_actuators" >}})
-   [Piezoelectric Actuators]({{< relref "piezoelectric_actuators" >}})
